@@ -65,6 +65,10 @@ class FrameworkParquetLoader(FrameworkTransformer):
         merge_schema: bool = self.getMergeSchema()
         limit: int = self.getLimit()
 
+        progress_logger and progress_logger.write_to_log(
+            f"Loading parquet file for view {view}: {path}"
+        )
+
         with ProgressLogMetric(
             name=f"{name or view}_table_loader", progress_logger=progress_logger
         ):
